==> mythgallery_0.16.orig.tar.gz: mythgallery-0.16/i18n/mythgallery_nl.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>IconView</name>
    <message>
        <source>Import pictures?</source>
        <translation>Foto&apos;s importeren?</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Neen</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>Nothing found to import</source>
        <translation>Niets gevonden om te importeren</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>Sorry: OpenGL support not available</source>
        <translation>Geen OpenGL ondersteuning aanwezig</translation>
    </message>
    <message>
        <source>SlideShow</source>
        <translation>Diashow</translation>
    </message>
    <message>
        <source>Rotate CW</source>
        <translation>Draai WZ</translation>
    </message>
    <message>
        <source>Rotate CCW</source>
        <translation>Draai TWZ</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importeren</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Directory that holds images</source>
        <translation>Map met foto&apos;s</translation>
    </message>
    <message>
        <source>This directory must exist and MythGallery needs to have read permission.</source>
        <translation>Deze map moet bestaan en we moeten leesrechten hebben</translation>
    </message>
    <message>
        <source>Paths to import images from</source>
        <translation>Foto&apos;s importeren uit</translation>
    </message>
    <message>
        <source>Type of transition</source>
        <translation>Type overgang</translation>
    </message>
    <message>
        <source>Type of background</source>
        <translation>Achtergrond</translation>
    </message>
    <message>
        <source>This is the number of seconds to display each picture.</source>
        <translation>Aantal seconden voor elke foto.</translation>
    </message>
    <message>
        <source>MythGallery Settings</source>
        <translation>Foto instellingen</translation>
    </message>
    <message>
        <source>This is a colon separated list of paths. If the path in the list is a directory, its contents will be copied. If it is an executable, it will be run.</source>
        <translation>Geef hier de lijst van mappen vanwaar u wil importeren. Als je hier een script ingeeft wordt dit uitgevoerd.</translation>
    </message>
    <message>
        <source>This is the type of transition used between pictures in slideshow mode.</source>
        <translation>Dit is het overganstype dat gebruikt wordt in diashow mode.</translation>
    </message>
    <message>
        <source>This is the type of background for each picture in single view mode.</source>
        <translation>Dit is het type achtergrond voor elke foto.</translation>
    </message>
    <message>
        <source>Slideshow Delay</source>
        <translation>Diashow pausetijd</translation>
    </message>
    <message>
        <source>Use OpenGL transitions</source>
        <translation>Gebruik OpenGL overgang</translation>
    </message>
    <message>
        <source>Check this to enable OpenGL based slideshow transitions</source>
        <translation>Vink dit aan om de OpenGL overgangen te kunnen gebruiken</translation>
    </message>
    <message>
        <source>Type of OpenGL transition</source>
        <translation>Type OpenGL overgang</translation>
    </message>
    <message>
        <source>This is the type of OpenGL transition used between pictures in slideshow mode.</source>
        <translation>Dit is het type OpenGL overgang die gebruikt wordt in diashow mode.</translation>
    </message>
    <message>
        <source>Gallery Directory does not exist or is unreadable.</source>
        <translation>Fotomap bestaat niet of is onleesbaar.</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>SingleView</name>
    <message>
        <source>Bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Breedte</translation>
    </message>
    <message>
        <source>Height</source>
        <translation>Hoogte</translation>
    </message>
    <message>
        <source>Pixel Count</source>
        <translation>Pixels</translation>
    </message>
    <message>
        <source>Rotation Angle</source>
        <translation>Draaihoek</translation>
    </message>
    <message>
        <source>pixels</source>
        <translation>punten</translation>
    </message>
    <message>
        <source>megapixels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>degrees</source>
        <translation>graden</translation>
    </message>
    <message>
        <source>Created: </source>
        <translation>Gemaakt: </translation>
    </message>
    <message>
        <source>Modified: </source>
        <translation>Aangepast: </translation>
    </message>
    <message>
        <source>Folder: </source>
        <translation>Map: </translation>
    </message>
</context>
</TS>

==> mythgallery_0.17.orig.tar.gz: mythgallery-0.17/i18n/mythgallery_nl.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>GLSingleView</name>
    <message>
        <source>Folder: </source>
        <translation>Map: </translation>
    </message>
    <message>
        <source>Created: </source>
        <translation>Gemaakt: </translation>
    </message>
    <message>
        <source>Modified: </source>
        <translation>Aangepast: </translation>
    </message>
    <message>
        <source>Bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Breedte</translation>
    </message>
    <message>
        <source>pixels</source>
        <translation>punten</translation>
    </message>
    <message>
        <source>Height</source>
        <translation>Hoogte</translation>
    </message>
    <message>
        <source>Pixel Count</source>
        <translation>Aantal pixels</translation>
    </message>
    <message>
        <source>megapixels</source>
        <translation>megapixels</translation>
    </message>
    <message>
        <source>Rotation Angle</source>
        <translation>Draaihoek</translation>
    </message>
    <message>
        <source>degrees</source>
        <translation>graden</translation>
    </message>
</context>
<context>
    <name>IconView</name>
    <message>
        <source>Import pictures?</source>
        <translation>Foto&apos;s importeren?</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Neen</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>Nothing found to import</source>
        <translation>Niets gevonden om te importeren</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>Sorry: OpenGL support not available</source>
        <translation>Geen OpenGL ondersteuning aanwezig</translation>
    </message>
    <message>
        <source>SlideShow</source>
        <translation>Diashow</translation>
    </message>
    <message>
        <source>Rotate CW</source>
        <translation>Draai WZ</translation>
    </message>
    <message>
        <source>Rotate CCW</source>
        <translation>Draai TWZ</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importeren</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>Random</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Directory that holds images</source>
        <translation>Map met foto&apos;s</translation>
    </message>
    <message>
        <source>This directory must exist and MythGallery needs to have read permission.</source>
        <translation>Deze map moet bestaan en we moeten leesrechten hebben</translation>
    </message>
    <message>
        <source>Paths to import images from</source>
        <translation>Foto&apos;s importeren uit</translation>
    </message>
    <message>
        <source>Type of transition</source>
        <translation>Type overgang</translation>
    </message>
    <message>
        <source>Type of background</source>
        <translation>Achtergrond</translation>
    </message>
    <message>
        <source>This is the number of seconds to display each picture.</source>
        <translation>Aantal seconden voor elke foto.</translation>
    </message>
    <message>
        <source>MythGallery Settings</source>
        <translation>Foto instellingen</translation>
    </message>
    <message>
        <source>This is a colon separated list of paths. If the path in the list is a directory, its contents will be copied. If it is an executable, it will be run.</source>
        <translation>Geef hier de lijst van mappen vanwaar u wil importeren. Als je hier een script ingeeft wordt dit uitgevoerd.</translation>
    </message>
    <message>
        <source>This is the type of transition used between pictures in slideshow mode.</source>
        <translation>Dit is het overganstype dat gebruikt wordt in diashow modus.</translation>
    </message>
    <message>
        <source>This is the type of background for each picture in single view mode.</source>
        <translation>Dit is het type achtergrond voor elke foto.</translation>
    </message>
    <message>
        <source>Slideshow Delay</source>
        <translation>Diashow vertraging</translation>
    </message>
    <message>
        <source>Use OpenGL transitions</source>
        <translation>Gebruik OpenGL overgang</translation>
    </message>
    <message>
        <source>Check this to enable OpenGL based slideshow transitions</source>
        <translation>Vink dit aan om de OpenGL overgangen te kunnen gebruiken</translation>
    </message>
    <message>
        <source>Type of OpenGL transition</source>
        <translation>Type OpenGL overgang</translation>
    </message>
    <message>
        <source>This is the type of OpenGL transition used between pictures in slideshow mode.</source>
        <translation>Dit is het type OpenGL overgang die gebruikt wordt in diashow modus.</translation>
    </message>
    <message>
        <source>Gallery Directory does not exist or is unreadable.</source>
        <translation>Fotomap bestaat niet of is onleesbaar.</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Command run to display movie files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This command is executed whenever a movie file is selected</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SingleView</name>
    <message>
        <source>Bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Breedte</translation>
    </message>
    <message>
        <source>Height</source>
        <translation>Hoogte</translation>
    </message>
    <message>
        <source>Pixel Count</source>
        <translation>Pixels</translation>
    </message>
    <message>
        <source>Rotation Angle</source>
        <translation>Draaihoek</translation>
    </message>
    <message>
        <source>pixels</source>
        <translation>punten</translation>
    </message>
    <message>
        <source>megapixels</source>
        <translation>megapixels</translation>
    </message>
    <message>
        <source>degrees</source>
        <translation>graden</translation>
    </message>
    <message>
        <source>Created: </source>
        <translation>Gemaakt: </translation>
    </message>
    <message>
        <source>Modified: </source>
        <translation>Aangepast: </translation>
    </message>
    <message>
        <source>Folder: </source>
        <translation>Map: </translation>
    </message>
</context>
</TS>
